pub trait IterableDataset: Send + Sync {
type Item;
type Iter: Iterator<Item = Result<Self::Item>> + Send;
// Required method
fn iter(&self) -> Self::Iter;
}Expand description
An iterable-style dataset
Represents a dataset that can be iterated over but may not support random access or have a known length.