pub struct PorterStemmer;Expand description
Porter stemmer implementation for English word stemming
This is a simplified implementation of the Porter stemming algorithm, which reduces words to their base forms by removing common suffixes.