pub struct TensorPool<T> { /* private fields */ }Expand description
Memory pool for reusing allocated tensors to avoid allocation/deallocation overhead
This pool maintains a collection of pre-allocated vectors that can be reused to avoid the overhead of memory allocation and deallocation in tight loops.
Implementations
Sourceimpl<T: Clone + Default> TensorPool<T>
impl<T: Clone + Default> TensorPool<T>
Sourcepub fn get(&self, capacity: usize) -> Vec<T>
pub fn get(&self, capacity: usize) -> Vec<T>
Get a tensor from the pool or allocate a new one
If a suitable tensor is available in the pool, it will be reused. Otherwise, a new tensor will be allocated.
Sourcepub fn return_tensor(&self, tensor: Vec<T>)
pub fn return_tensor(&self, tensor: Vec<T>)
Return a tensor to the pool
The tensor will be stored in the pool for future reuse if there’s space.