pub struct PersistentWorkerPool<D, C>where
D: Dataset + Clone + Send + Sync + 'static,
C: Collate<D::Item> + Clone + Send + Sync + 'static,
D::Item: Send + 'static,
C::Output: Send + 'static,{ /* private fields */ }Expand description
Persistent worker pool that keeps workers alive across epochs
Unlike the regular WorkerPool, this implementation keeps worker threads alive between epochs, reducing the overhead of thread creation and destruction. This is particularly useful for training scenarios with multiple epochs.
Examples
use std::sync::Arc;
use torsh_data::dataloader::workers::PersistentWorkerPool;
use torsh_data::dataset::TensorDataset;
use torsh_data::collate::DefaultCollate;
let dataset = Arc::new(TensorDataset::new(vec![1, 2, 3, 4, 5]));
let collate_fn = Arc::new(DefaultCollate);
let worker_pool = PersistentWorkerPool::new(dataset, collate_fn, 4);
// Use across multiple epochs
for epoch in 0..10 {
worker_pool.reset_for_epoch().unwrap();
// Submit tasks for this epoch
}
// Shutdown when done
worker_pool.shutdown().unwrap();Implementations
Sourceimpl<D, C> PersistentWorkerPool<D, C>
impl<D, C> PersistentWorkerPool<D, C>
Sourcepub fn get_result(&self) -> Result<WorkerResult<C::Output>>
pub fn get_result(&self) -> Result<WorkerResult<C::Output>>
Get a result from the persistent worker pool
This method blocks until a result is available from any worker.
Returns
The next available worker result
Sourcepub fn get_result_timeout(
&self,
timeout: Duration,
) -> Result<WorkerResult<C::Output>>
pub fn get_result_timeout( &self, timeout: Duration, ) -> Result<WorkerResult<C::Output>>
Sourcepub fn try_get_result(&self) -> Option<WorkerResult<C::Output>>
pub fn try_get_result(&self) -> Option<WorkerResult<C::Output>>
Sourcepub fn num_workers(&self) -> usize
pub fn num_workers(&self) -> usize
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Sourcepub fn shutdown(&self) -> Result<()>
pub fn shutdown(&self) -> Result<()>
Shutdown the persistent worker pool
This method gracefully shuts down all worker threads and should be called when the pool is no longer needed.
Returns
Result indicating success or failure of shutdown operation
Sourcepub fn reset_for_epoch(&self) -> Result<()>
pub fn reset_for_epoch(&self) -> Result<()>
Reset the pool for a new epoch (clears any pending tasks)
This method can be called between epochs to reset the pool state. In the current implementation, this is a placeholder for future epoch-specific optimizations.
Returns
Result indicating success or failure of reset operation