macro_rules! simple_transform {
($name:ident, $input:ty, $output:ty, $transform_fn:expr) => { ... };
($name:ident, $input:ty, $output:ty, $transform_fn:expr, deterministic = $det:literal) => { ... };
}Expand description
Macro to create simple stateless transforms
This macro generates a transform struct and implementation for simple cases where the transform logic can be expressed as a function.