pub struct BatchingSampler<S: Sampler> { /* private fields */ }Expand description
Wrapper that converts any sampler into a batch sampler
This sampler takes an underlying sampler and groups its output into batches
of a specified size. The last batch may be smaller than the batch size
unless drop_last is set to true.
Examples
ⓘ
use torsh_data::sampler::{SequentialSampler, BatchingSampler, BatchSampler};
let base_sampler = SequentialSampler::new(10);
let batch_sampler = BatchingSampler::new(base_sampler, 3, false);
let batches: Vec<Vec<usize>> = batch_sampler.iter().collect();
assert_eq!(batches.len(), 4); // [0,1,2], [3,4,5], [6,7,8], [9]Implementations
Sourceimpl<S: Sampler> BatchingSampler<S>
impl<S: Sampler> BatchingSampler<S>
Sourcepub fn batch_size(&self) -> usize
pub fn batch_size(&self) -> usize
Get the batch size
Sourcepub fn into_sampler(self) -> S
pub fn into_sampler(self) -> S
Get the underlying sampler by value
Sourcepub fn into_distributed(
self,
num_replicas: usize,
rank: usize,
) -> BatchingSampler<DistributedWrapper<S>>
pub fn into_distributed( self, num_replicas: usize, rank: usize, ) -> BatchingSampler<DistributedWrapper<S>>
Convert this batching sampler into a distributed version
This creates a distributed wrapper around the underlying sampler and then wraps it with a new BatchingSampler.
Arguments
num_replicas- Total number of processesrank- Current process rank (0-based)